@@ -11,7 +11,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::JMASLAK;
 # ABSTRACT: JMASLAK's Plugin Bundle
-$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '0.003';
+$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '0.004';
 
 use Moose;
 use Dist::Zilla;
@@ -65,7 +65,7 @@ sub configure {
 
     $self->add_plugins($self->_contributing_plugin());
     $self->add_plugins($self->_copy_files_from_build());
-    $self->add_plugins($self->_covenant());
+    $self->add_plugins($self->_covenant_plugin());
     $self->add_plugins($self->_mailmap_plugin());
     $self->add_plugins($self->_todo_plugin());
     $self->add_plugins($self->_travis_plugin());
@@ -217,7 +217,7 @@ Dist::Zilla::PluginBundle::Author::JMASLAK - JMASLAK's Plugin Bundle
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
